Powershell Lexer
This module provides powershell lexer functionality for the Oaks project.
Modules
- token_
type - Token type definitions.
Structs
- Power
Shell Lexer - Lexer for the PowerShell language.
This module provides powershell lexer functionality for the Oaks project.